==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/correios_sfe/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Correios SFE',
    'version': '7.0.21.12.14',
    'category': 'Financeiro',
    'description': """Modulo para importacao de faturas dos Correios""",
    'author': "Sig Informatica Ltda",
    'website': 'http://www.siginformatica.com',
    'depends': ['financeiro'],
    'data': [
        'wizard/wizard_importa_encomendas.xml',
        'views/action.xml',
        'views/menu.xml',
        'security/ir.model.access.csv'
    ],
    'installable': True,
    "application": True,
    'active': False,
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/correios_sfe/__openerp__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Correios SFE',
    'version': '7.0.2310.2',
    'category': 'Financeiro',
    'description': """Modulo para importacao de faturas dos Correios""",
    'author': "Sig Informatica Ltda",
    'website': 'http://www.siginformatica.com',
    'depends': ['financeiro'],
    'data': [
        'wizard/wizard_importa_encomendas.xml',
        'views/action.xml',
        'views/menu.xml',
        'security/ir.model.access.csv'
    ],
    'installable': True,
    "application": True,
    'active': False,
}
